@@ -24,3 +24,15 @@
 
 /* Define if you have the inet_aton function.  */
 #undef HAVE_INET_ATON
+
+/* Define if you want to disable network support */
+#undef NO_NETWORK
+
+/* Define if you have gzdopen() in -lz, for native support of .gz files */
+#undef HAVE_GZDOPEN
+
+/* Define if you have bzdopen() in -lbz2, for native support of .bz2 files */
+#undef HAVE_BZDOPEN
+
+/* Define if you have a new bzip2 implementation that uses BZ2_name */
+#undef HAVE_NEW_BZDOPEN
