@@ -1,3 +1,5 @@
+#ifndef _ALGORITHMS_H
+#define _ALOGIRTHMS_H
 /*
 	Algorithms!
 */
@@ -125,3 +127,4 @@ char *algorithm_names[256]={	"Uncompressed",
 extern int (*(algorithms[256]))();
 extern char *algorithm_names[256];
 #endif
+#endif
