@@ -60,7 +60,11 @@ int comp_bzlib_compress(unsigned char *prev_block, unsigned char *curr_block, ch
 	unsigned int dest_size=(DACT_BLK_SIZE*2);
 	int retval;
 
-	retval=bzBuffToBuffCompress(out_block, &dest_size, curr_block, blk_size, 1, 0, 9);
+#ifdef HAVE_NEW_BZ2
+	retval=BZ2_bzBuffToBuffCompress(out_block, &dest_size, curr_block, blk_size, 9, 0, 9);
+#else
+	retval=bzBuffToBuffCompress(out_block, &dest_size, curr_block, blk_size, 9, 0, 9);
+#endif
 	if (retval!=BZ_OK) return(-1);
 
 	return(dest_size);
@@ -70,7 +74,11 @@ int comp_bzlib_decompress(unsigned char *prev_block, unsigned char *curr_block,
 	unsigned int dest_size=(DACT_BLK_SIZE*2);
 	int retval;
 
+#ifdef HAVE_NEW_BZ2
+	retval=BZ2_bzBuffToBuffDecompress(out_block, &dest_size, curr_block, blk_size, 0, 0);
+#else
 	retval=bzBuffToBuffDecompress(out_block, &dest_size, curr_block, blk_size, 0, 0);
+#endif
 
 	if (retval!=BZ_OK) return(0);
 	return(dest_size);
