@@ -1,3 +1,7 @@
+#ifndef _COMP_FACTOR_H
+#define _COMP_FACTOR_H
+/* XXX: Add module support! */
 int comp_factor_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_factor_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_factor_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
+#endif
