@@ -1,3 +1,5 @@
+#ifndef _COMP_MZLIB2_H
+#define _COMP_MZLIB2_H
 #include "dact.h"
 #include "config.h"
 
@@ -8,3 +10,4 @@ int comp_mzlib2_algo(int mode, unsigned char *prev_block, unsigned char *curr_bl
 int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_mzlib2_decompress(unsigned char *prev_block, unsigned char *curr_block,unsigned char *out_block, int blk_size);
 #endif
+#endif
